// Thine package.
package kirk.gui.dialog;

// Import Fraim.
import java.awt.Frame;

/**
 * This class retrieves the value inputted in an <code>InputDialog</code>.
 * 
 * You retrieve the <code>String</code> with
 * <code>InputRetriever.getInputValue(Frame owner, String message, int columns)
 * </code>.
 * 
 * @author Berend "Kirk" Wouda
 * @version 1
 * @see kirk.gui.dialog.InputDialog
 */
public class InputRetriever implements InputAcceptor {
	/**
	 * Constructs a new <code>InputRetriever</code>.
	 */
	protected InputRetriever(Frame owner, String message, int width, int height, int columns) {
		// Pop up the Input dialog.
		SingleInputDialog inputdialog = new SingleInputDialog(owner, this, message, width, height, columns);
		
		// Show it.
		inputdialog.show();
	}
	
	
	/**
	 * Sets the input value to the passed value.
	 * Only the <code>InputDialog</code> that was constructed by this class should
	 * use this method.
	 * 
	 * @param value The value from the <code>InputDialog</code>.
	 */
	public void setInputValue(Object value) {
		// Check whether the passed object is a String, and if it is, set the home
		// value to that String.
		if(value instanceof String)  this.value = (String) value;
		// If it isn't, the value is set to null.
		else  this.value = null;
	}
	
	/**
	 * Returns the value retrieved from the <code>InputDialog</code>. 
	 * 
	 * @return The value retrieved from the <code>InputDialog</code>.
	 */
	protected String getInputValue() {
		// Return the value.
		return value;
	}
	
	
	/**
	 * The value retrieved from the <code>InputDialog</code>.
	 */
	protected String value;
	
	
	/**
	 * Creates an <code>InputRetriever</code> and retrieves its value.
	 * 
	 * @param owner The <code>Frame</code> a <code>Dialog</code> has to be popped up
	 * on. 
	 * @param message The message to be displayed on the popup.
	 * @param columns The amount of characters that have to fit in the input field.
	 * @return A <code>String</code> that contains the contents of the input field.
	 */
	public static String getInputValue(Frame owner, String message, int width, int height, int columns) {
		// Construct a new InputReceiver.
		InputRetriever inputretreiver = new InputRetriever(owner, message, width, height, columns);
		
		// Retrieve the value and return it.
		return inputretreiver.getInputValue();
	}
}
